/*
    w32loader
    copyright (c) 1998-2007 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/
#include "oleaut32.h"


#ifdef W32LDR_HEADER
#include "ole32.h"
typedef struct _ITypeLib ITypeLib;
typedef enum _REGKIND
{
  REGKIND_DEFAULT,
  REGKIND_REGISTER,
  REGKIND_NONE
} REGKIND;
#endif /* W32LDR_HEADER */


/* BSTR_UserFree ordinal = 286, argument = 0 temporary */
static DWORD WINAPI BSTR_UserFree (VOID)
{
  return 0;
}


/* BSTR_UserMarshal ordinal = 284, argument = 0 temporary */
static DWORD WINAPI BSTR_UserMarshal (VOID)
{
  return 0;
}


/* BSTR_UserSize ordinal = 283, argument = 0 temporary */
static DWORD WINAPI BSTR_UserSize (VOID)
{
  return 0;
}


/* BSTR_UserUnmarshal ordinal = 285, argument = 0 temporary */
static DWORD WINAPI BSTR_UserUnmarshal (VOID)
{
  return 0;
}


/* BstrFromVector ordinal = 414, argument = 0 temporary */
static DWORD WINAPI BstrFromVector (VOID)
{
  return 0;
}


/* ClearCustData ordinal = 171, argument = 0 temporary */
static DWORD WINAPI ClearCustData (VOID)
{
  return 0;
}


/* CreateDispTypeInfo ordinal = 31, argument = 0 temporary */
static DWORD WINAPI CreateDispTypeInfo (VOID)
{
  return 0;
}


/* CreateErrorInfo ordinal = 202, argument = 0 temporary */
static DWORD WINAPI CreateErrorInfo (VOID)
{
  return 0;
}


/* CreateStdDispatch ordinal = 32, argument = 0 temporary */
static DWORD WINAPI CreateStdDispatch (VOID)
{
  return 0;
}


/* CreateTypeLib ordinal = 160, argument = 0 temporary */
static DWORD WINAPI CreateTypeLib (VOID)
{
  return 0;
}


/* CreateTypeLib2 ordinal = 180, argument = 0 temporary */
static DWORD WINAPI CreateTypeLib2 (VOID)
{
  return 0;
}


/* DispCallFunc ordinal = 146, argument = 0 temporary */
static DWORD WINAPI DispCallFunc (VOID)
{
  return 0;
}


/* DispGetIDsOfNames ordinal = 29, argument = 0 temporary */
static DWORD WINAPI DispGetIDsOfNames (VOID)
{
  return 0;
}


/* DispGetParam ordinal = 28, argument = 0 temporary */
static DWORD WINAPI DispGetParam (VOID)
{
  return 0;
}


/* DispInvoke ordinal = 30, argument = 0 temporary */
static DWORD WINAPI DispInvoke (VOID)
{
  return 0;
}


/* DllCanUnloadNow ordinal = 410, argument = 0 temporary */
static DWORD WINAPI DllCanUnloadNow (VOID)
{
  return 0;
}


/* DllGetClassObject ordinal = 1, argument = 0 temporary */
static DWORD WINAPI DllGetClassObject (VOID)
{
  return 0;
}


/* DllRegisterServer ordinal = 320, argument = 0 temporary */
static DWORD WINAPI DllRegisterServer (VOID)
{
  return 0;
}


/* DllUnregisterServer ordinal = 321, argument = 0 temporary */
static DWORD WINAPI DllUnregisterServer (VOID)
{
  return 0;
}


/* DosDateTimeToVariantTime ordinal = 14, argument = 0 temporary */
static DWORD WINAPI DosDateTimeToVariantTime (VOID)
{
  return 0;
}


/* GetActiveObject ordinal = 35, argument = 0 temporary */
static DWORD WINAPI GetActiveObject (VOID)
{
  return 0;
}


/* GetAltMonthNames ordinal = 332, argument = 0 temporary */
static DWORD WINAPI GetAltMonthNames (VOID)
{
  return 0;
}


/* GetErrorInfo ordinal = 200, argument = 0 temporary */
static DWORD WINAPI GetErrorInfo (VOID)
{
  return 0;
}


/* GetRecordInfoFromGuids ordinal = 322, argument = 0 temporary */
static DWORD WINAPI GetRecordInfoFromGuids (VOID)
{
  return 0;
}


/* GetRecordInfoFromTypeInfo ordinal = 323, argument = 0 temporary */
static DWORD WINAPI GetRecordInfoFromTypeInfo (VOID)
{
  return 0;
}


/* GetVarConversionLocaleSetting ordinal = 326, argument = 0 temporary */
static DWORD WINAPI GetVarConversionLocaleSetting (VOID)
{
  return 0;
}


/* LHashValOfNameSys ordinal = 165, argument = 0 temporary */
/* DWORD WINAPI LHashValOfNameSys (VOID) */


/* LHashValOfNameSysA ordinal = 166, argument = 0 temporary */
static DWORD WINAPI LHashValOfNameSysA (VOID)
{
  return 0;
}


/* LPSAFEARRAY_Marshal ordinal = 296, argument = 0 temporary */
static DWORD WINAPI LPSAFEARRAY_Marshal (VOID)
{
  return 0;
}


/* LPSAFEARRAY_Size ordinal = 295, argument = 0 temporary */
static DWORD WINAPI LPSAFEARRAY_Size (VOID)
{
  return 0;
}


/* LPSAFEARRAY_Unmarshal ordinal = 297, argument = 0 temporary */
static DWORD WINAPI LPSAFEARRAY_Unmarshal (VOID)
{
  return 0;
}


/* LPSAFEARRAY_UserFree ordinal = 294, argument = 0 temporary */
static DWORD WINAPI LPSAFEARRAY_UserFree (VOID)
{
  return 0;
}


/* LPSAFEARRAY_UserMarshal ordinal = 292, argument = 0 temporary */
static DWORD WINAPI LPSAFEARRAY_UserMarshal (VOID)
{
  return 0;
}


/* LPSAFEARRAY_UserSize ordinal = 291, argument = 0 temporary */
static DWORD WINAPI LPSAFEARRAY_UserSize (VOID)
{
  return 0;
}


/* LPSAFEARRAY_UserUnmarshal ordinal = 293, argument = 0 temporary */
static DWORD WINAPI LPSAFEARRAY_UserUnmarshal (VOID)
{
  return 0;
}


/* LoadRegTypeLib ordinal = 162, argument = 0 temporary */
static DWORD WINAPI LoadRegTypeLib (VOID)
{
  return 0;
}


/* LoadTypeLib ordinal = 161, argument = 0 */
HRESULT WINAPI LoadTypeLib (LPCOLESTR szFile, ITypeLib **pptLib)
{
  return LoadTypeLibEx (szFile, REGKIND_DEFAULT, pptLib);
}


/* LoadTypeLibEx ordinal = 183, argument = 0 */
HRESULT WINAPI LoadTypeLibEx (LPCOLESTR szFile, REGKIND regkind, ITypeLib **pptLib)
{
  return TYPE_E_LIBNOTREGISTERED;
}


/* OACreateTypeLib2 ordinal = 144, argument = 12 temporary */
static DWORD WINAPI OACreateTypeLib2 (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2)
{
  return 0;
}


/* OaBuildVersion ordinal = 170, argument = 0 temporary */
static DWORD WINAPI OaBuildVersion (VOID)
{
  return 0;
}


/* OleCreateFontIndirect ordinal = 420, argument = 0 temporary */
static DWORD WINAPI OleCreateFontIndirect (VOID)
{
  return 0;
}


/* OleCreatePictureIndirect ordinal = 419, argument = 0 temporary */
static DWORD WINAPI OleCreatePictureIndirect (VOID)
{
  return 0;
}


/* OleCreatePropertyFrame ordinal = 417, argument = 0 temporary */
static DWORD WINAPI OleCreatePropertyFrame (VOID)
{
  return 0;
}


/* OleCreatePropertyFrameIndirect ordinal = 416, argument = 0 temporary */
static DWORD WINAPI OleCreatePropertyFrameIndirect (VOID)
{
  return 0;
}


/* OleIconToCursor ordinal = 415, argument = 0 temporary */
static DWORD WINAPI OleIconToCursor (VOID)
{
  return 0;
}


/* OleLoadPicture ordinal = 418, argument = 0 temporary */
static DWORD WINAPI OleLoadPicture (VOID)
{
  return 0;
}


/* OleLoadPictureEx ordinal = 401, argument = 0 temporary */
static DWORD WINAPI OleLoadPictureEx (VOID)
{
  return 0;
}


/* OleLoadPictureFile ordinal = 422, argument = 0 temporary */
static DWORD WINAPI OleLoadPictureFile (VOID)
{
  return 0;
}


/* OleLoadPictureFileEx ordinal = 402, argument = 0 temporary */
static DWORD WINAPI OleLoadPictureFileEx (VOID)
{
  return 0;
}


/* OleLoadPicturePath ordinal = 424, argument = 0 temporary */
static DWORD WINAPI OleLoadPicturePath (VOID)
{
  return 0;
}


/* OleSavePictureFile ordinal = 423, argument = 0 temporary */
static DWORD WINAPI OleSavePictureFile (VOID)
{
  return 0;
}


/* OleTranslateColor ordinal = 421, argument = 0 temporary */
static DWORD WINAPI OleTranslateColor (VOID)
{
  return 0;
}


/* QueryPathOfRegTypeLib ordinal = 164, argument = 0 temporary */
static DWORD WINAPI QueryPathOfRegTypeLib (VOID)
{
  return 0;
}


/* RegisterActiveObject ordinal = 33, argument = 0 temporary */
static DWORD WINAPI RegisterActiveObject (VOID)
{
  return 0;
}


/* RegisterTypeLib ordinal = 163, argument = 0 */
HRESULT WINAPI RegisterTypeLib (ITypeLib *ptlib, OLECHAR *szFullPath, OLECHAR *szHelpDir)
{
  return E_FAIL;
}


/* RevokeActiveObject ordinal = 34, argument = 0 temporary */
static DWORD WINAPI RevokeActiveObject (VOID)
{
  return 0;
}


/* SafeArrayAccessData ordinal = 23, argument = 0 temporary */
static DWORD WINAPI SafeArrayAccessData (VOID)
{
  return 0;
}


/* SafeArrayAllocData ordinal = 37, argument = 0 temporary */
static DWORD WINAPI SafeArrayAllocData (VOID)
{
  return 0;
}


/* SafeArrayAllocDescriptor ordinal = 36, argument = 0 temporary */
static DWORD WINAPI SafeArrayAllocDescriptor (VOID)
{
  return 0;
}


/* SafeArrayAllocDescriptorEx ordinal = 41, argument = 0 temporary */
static DWORD WINAPI SafeArrayAllocDescriptorEx (VOID)
{
  return 0;
}


/* SafeArrayCopy ordinal = 27, argument = 0 temporary */
static DWORD WINAPI SafeArrayCopy (VOID)
{
  return 0;
}


/* SafeArrayCopyData ordinal = 412, argument = 0 temporary */
static DWORD WINAPI SafeArrayCopyData (VOID)
{
  return 0;
}


/* SafeArrayCreate ordinal = 15, argument = 0 temporary */
static DWORD WINAPI SafeArrayCreate (VOID)
{
  return 0;
}


/* SafeArrayCreateEx ordinal = 42, argument = 0 temporary */
static DWORD WINAPI SafeArrayCreateEx (VOID)
{
  return 0;
}


/* SafeArrayCreateVector ordinal = 411, argument = 0 temporary */
static DWORD WINAPI SafeArrayCreateVector (VOID)
{
  return 0;
}


/* SafeArrayCreateVectorEx ordinal = 43, argument = 0 temporary */
static DWORD WINAPI SafeArrayCreateVectorEx (VOID)
{
  return 0;
}


/* SafeArrayDestroy ordinal = 16, argument = 0 temporary */
static DWORD WINAPI SafeArrayDestroy (VOID)
{
  return 0;
}


/* SafeArrayDestroyData ordinal = 39, argument = 0 temporary */
static DWORD WINAPI SafeArrayDestroyData (VOID)
{
  return 0;
}


/* SafeArrayDestroyDescriptor ordinal = 38, argument = 0 temporary */
static DWORD WINAPI SafeArrayDestroyDescriptor (VOID)
{
  return 0;
}


/* SafeArrayGetDim ordinal = 17, argument = 0 temporary */
static DWORD WINAPI SafeArrayGetDim (VOID)
{
  return 0;
}


/* SafeArrayGetElement ordinal = 25, argument = 0 temporary */
static DWORD WINAPI SafeArrayGetElement (VOID)
{
  return 0;
}


/* SafeArrayGetElemsize ordinal = 18, argument = 0 temporary */
static DWORD WINAPI SafeArrayGetElemsize (VOID)
{
  return 0;
}


/* SafeArrayGetIID ordinal = 67, argument = 0 temporary */
static DWORD WINAPI SafeArrayGetIID (VOID)
{
  return 0;
}


/* SafeArrayGetLBound ordinal = 20, argument = 0 temporary */
static DWORD WINAPI SafeArrayGetLBound (VOID)
{
  return 0;
}


/* SafeArrayGetRecordInfo ordinal = 45, argument = 0 temporary */
static DWORD WINAPI SafeArrayGetRecordInfo (VOID)
{
  return 0;
}


/* SafeArrayGetUBound ordinal = 19, argument = 0 temporary */
static DWORD WINAPI SafeArrayGetUBound (VOID)
{
  return 0;
}


/* SafeArrayGetVartype ordinal = 77, argument = 0 temporary */
static DWORD WINAPI SafeArrayGetVartype (VOID)
{
  return 0;
}


/* SafeArrayLock ordinal = 21, argument = 0 temporary */
static DWORD WINAPI SafeArrayLock (VOID)
{
  return 0;
}


/* SafeArrayPtrOfIndex ordinal = 148, argument = 0 temporary */
static DWORD WINAPI SafeArrayPtrOfIndex (VOID)
{
  return 0;
}


/* SafeArrayPutElement ordinal = 26, argument = 0 temporary */
static DWORD WINAPI SafeArrayPutElement (VOID)
{
  return 0;
}


/* SafeArrayRedim ordinal = 40, argument = 0 temporary */
static DWORD WINAPI SafeArrayRedim (VOID)
{
  return 0;
}


/* SafeArraySetIID ordinal = 57, argument = 0 temporary */
static DWORD WINAPI SafeArraySetIID (VOID)
{
  return 0;
}


/* SafeArraySetRecordInfo ordinal = 44, argument = 0 temporary */
static DWORD WINAPI SafeArraySetRecordInfo (VOID)
{
  return 0;
}


/* SafeArrayUnaccessData ordinal = 24, argument = 0 temporary */
static DWORD WINAPI SafeArrayUnaccessData (VOID)
{
  return 0;
}


/* SafeArrayUnlock ordinal = 22, argument = 0 temporary */
static DWORD WINAPI SafeArrayUnlock (VOID)
{
  return 0;
}


/* SetErrorInfo ordinal = 201, argument = 0 temporary */
static DWORD WINAPI SetErrorInfo (VOID)
{
  return 0;
}


/* SetVarConversionLocaleSetting ordinal = 325, argument = 0 temporary */
static DWORD WINAPI SetVarConversionLocaleSetting (VOID)
{
  return 0;
}


/* SysAllocString ordinal = 2, argument = 0 temporary */
static DWORD WINAPI SysAllocString (VOID)
{
  return 0;
}


/* SysAllocStringByteLen ordinal = 150, argument = 0 temporary */
static DWORD WINAPI SysAllocStringByteLen (VOID)
{
  return 0;
}


/* SysAllocStringLen ordinal = 4, argument = 0 temporary */
static DWORD WINAPI SysAllocStringLen (VOID)
{
  return 0;
}


/* SysFreeString ordinal = 6, argument = 0 temporary */
static DWORD WINAPI SysFreeString (VOID)
{
  return 0;
}


/* SysReAllocString ordinal = 3, argument = 0 temporary */
static DWORD WINAPI SysReAllocString (VOID)
{
  return 0;
}


/* SysReAllocStringLen ordinal = 5, argument = 0 temporary */
static DWORD WINAPI SysReAllocStringLen (VOID)
{
  return 0;
}


/* SysStringByteLen ordinal = 149, argument = 0 temporary */
static DWORD WINAPI SysStringByteLen (VOID)
{
  return 0;
}


/* SysStringLen ordinal = 7, argument = 0 temporary */
static DWORD WINAPI SysStringLen (VOID)
{
  return 0;
}


/* SystemTimeToVariantTime ordinal = 184, argument = 0 temporary */
static DWORD WINAPI SystemTimeToVariantTime (VOID)
{
  return 0;
}


/* UnRegisterTypeLib ordinal = 186, argument = 0 temporary */
static DWORD WINAPI UnRegisterTypeLib (VOID)
{
  return 0;
}


/* UserBSTR_free_inst ordinal = 386, argument = 0 temporary */
static DWORD WINAPI UserBSTR_free_inst (VOID)
{
  return 0;
}


/* UserBSTR_free_local ordinal = 387, argument = 0 temporary */
static DWORD WINAPI UserBSTR_free_local (VOID)
{
  return 0;
}


/* UserBSTR_from_local ordinal = 384, argument = 0 temporary */
static DWORD WINAPI UserBSTR_from_local (VOID)
{
  return 0;
}


/* UserBSTR_to_local ordinal = 385, argument = 0 temporary */
static DWORD WINAPI UserBSTR_to_local (VOID)
{
  return 0;
}


/* UserEXCEPINFO_free_inst ordinal = 394, argument = 0 temporary */
static DWORD WINAPI UserEXCEPINFO_free_inst (VOID)
{
  return 0;
}


/* UserEXCEPINFO_free_local ordinal = 395, argument = 0 temporary */
static DWORD WINAPI UserEXCEPINFO_free_local (VOID)
{
  return 0;
}


/* UserEXCEPINFO_from_local ordinal = 392, argument = 0 temporary */
static DWORD WINAPI UserEXCEPINFO_from_local (VOID)
{
  return 0;
}


/* UserEXCEPINFO_to_local ordinal = 393, argument = 0 temporary */
static DWORD WINAPI UserEXCEPINFO_to_local (VOID)
{
  return 0;
}


/* UserHWND_free_inst ordinal = 382, argument = 0 temporary */
static DWORD WINAPI UserHWND_free_inst (VOID)
{
  return 0;
}


/* UserHWND_free_local ordinal = 383, argument = 0 temporary */
static DWORD WINAPI UserHWND_free_local (VOID)
{
  return 0;
}


/* UserHWND_from_local ordinal = 380, argument = 0 temporary */
static DWORD WINAPI UserHWND_from_local (VOID)
{
  return 0;
}


/* UserHWND_to_local ordinal = 381, argument = 0 temporary */
static DWORD WINAPI UserHWND_to_local (VOID)
{
  return 0;
}


/* UserMSG_free_inst ordinal = 398, argument = 0 temporary */
static DWORD WINAPI UserMSG_free_inst (VOID)
{
  return 0;
}


/* UserMSG_free_local ordinal = 399, argument = 0 temporary */
static DWORD WINAPI UserMSG_free_local (VOID)
{
  return 0;
}


/* UserMSG_from_local ordinal = 396, argument = 0 temporary */
static DWORD WINAPI UserMSG_from_local (VOID)
{
  return 0;
}


/* UserMSG_to_local ordinal = 397, argument = 0 temporary */
static DWORD WINAPI UserMSG_to_local (VOID)
{
  return 0;
}


/* UserVARIANT_free_inst ordinal = 390, argument = 0 temporary */
static DWORD WINAPI UserVARIANT_free_inst (VOID)
{
  return 0;
}


/* UserVARIANT_free_local ordinal = 391, argument = 0 temporary */
static DWORD WINAPI UserVARIANT_free_local (VOID)
{
  return 0;
}


/* UserVARIANT_from_local ordinal = 388, argument = 0 temporary */
static DWORD WINAPI UserVARIANT_from_local (VOID)
{
  return 0;
}


/* UserVARIANT_to_local ordinal = 389, argument = 0 temporary */
static DWORD WINAPI UserVARIANT_to_local (VOID)
{
  return 0;
}


/* VARIANT_UserFree ordinal = 290, argument = 0 temporary */
static DWORD WINAPI VARIANT_UserFree (VOID)
{
  return 0;
}


/* VARIANT_UserMarshal ordinal = 288, argument = 0 temporary */
static DWORD WINAPI VARIANT_UserMarshal (VOID)
{
  return 0;
}


/* VARIANT_UserSize ordinal = 287, argument = 0 temporary */
static DWORD WINAPI VARIANT_UserSize (VOID)
{
  return 0;
}


/* VARIANT_UserUnmarshal ordinal = 289, argument = 0 temporary */
static DWORD WINAPI VARIANT_UserUnmarshal (VOID)
{
  return 0;
}


/* VarAbs ordinal = 168, argument = 0 temporary */
static DWORD WINAPI VarAbs (VOID)
{
  return 0;
}


/* VarAdd ordinal = 141, argument = 0 temporary */
static DWORD WINAPI VarAdd (VOID)
{
  return 0;
}


/* VarAnd ordinal = 142, argument = 0 temporary */
static DWORD WINAPI VarAnd (VOID)
{
  return 0;
}


/* VarBoolFromCy ordinal = 124, argument = 0 temporary */
static DWORD WINAPI VarBoolFromCy (VOID)
{
  return 0;
}


/* VarBoolFromDate ordinal = 123, argument = 0 temporary */
static DWORD WINAPI VarBoolFromDate (VOID)
{
  return 0;
}


/* VarBoolFromDec ordinal = 236, argument = 0 temporary */
static DWORD WINAPI VarBoolFromDec (VOID)
{
  return 0;
}


/* VarBoolFromDisp ordinal = 126, argument = 0 temporary */
static DWORD WINAPI VarBoolFromDisp (VOID)
{
  return 0;
}


/* VarBoolFromI1 ordinal = 233, argument = 0 temporary */
static DWORD WINAPI VarBoolFromI1 (VOID)
{
  return 0;
}


/* VarBoolFromI2 ordinal = 119, argument = 0 temporary */
static DWORD WINAPI VarBoolFromI2 (VOID)
{
  return 0;
}


/* VarBoolFromI4 ordinal = 120, argument = 0 temporary */
static DWORD WINAPI VarBoolFromI4 (VOID)
{
  return 0;
}


/* VarBoolFromR4 ordinal = 121, argument = 0 temporary */
static DWORD WINAPI VarBoolFromR4 (VOID)
{
  return 0;
}


/* VarBoolFromR8 ordinal = 122, argument = 0 temporary */
static DWORD WINAPI VarBoolFromR8 (VOID)
{
  return 0;
}


/* VarBoolFromStr ordinal = 125, argument = 0 temporary */
static DWORD WINAPI VarBoolFromStr (VOID)
{
  return 0;
}


/* VarBoolFromUI1 ordinal = 118, argument = 0 temporary */
static DWORD WINAPI VarBoolFromUI1 (VOID)
{
  return 0;
}


/* VarBoolFromUI2 ordinal = 234, argument = 0 temporary */
static DWORD WINAPI VarBoolFromUI2 (VOID)
{
  return 0;
}


/* VarBoolFromUI4 ordinal = 235, argument = 0 temporary */
static DWORD WINAPI VarBoolFromUI4 (VOID)
{
  return 0;
}


/* VarBstrCat ordinal = 313, argument = 0 temporary */
static DWORD WINAPI VarBstrCat (VOID)
{
  return 0;
}


/* VarBstrCmp ordinal = 314, argument = 0 temporary */
static DWORD WINAPI VarBstrCmp (VOID)
{
  return 0;
}


/* VarBstrFromBool ordinal = 116, argument = 0 temporary */
static DWORD WINAPI VarBstrFromBool (VOID)
{
  return 0;
}


/* VarBstrFromCy ordinal = 113, argument = 0 temporary */
static DWORD WINAPI VarBstrFromCy (VOID)
{
  return 0;
}


/* VarBstrFromDate ordinal = 114, argument = 0 temporary */
static DWORD WINAPI VarBstrFromDate (VOID)
{
  return 0;
}


/* VarBstrFromDec ordinal = 232, argument = 0 temporary */
static DWORD WINAPI VarBstrFromDec (VOID)
{
  return 0;
}


/* VarBstrFromDisp ordinal = 115, argument = 0 temporary */
static DWORD WINAPI VarBstrFromDisp (VOID)
{
  return 0;
}


/* VarBstrFromI1 ordinal = 229, argument = 0 temporary */
static DWORD WINAPI VarBstrFromI1 (VOID)
{
  return 0;
}


/* VarBstrFromI2 ordinal = 109, argument = 0 temporary */
static DWORD WINAPI VarBstrFromI2 (VOID)
{
  return 0;
}


/* VarBstrFromI4 ordinal = 110, argument = 0 temporary */
static DWORD WINAPI VarBstrFromI4 (VOID)
{
  return 0;
}


/* VarBstrFromR4 ordinal = 111, argument = 0 temporary */
static DWORD WINAPI VarBstrFromR4 (VOID)
{
  return 0;
}


/* VarBstrFromR8 ordinal = 112, argument = 0 temporary */
static DWORD WINAPI VarBstrFromR8 (VOID)
{
  return 0;
}


/* VarBstrFromUI1 ordinal = 108, argument = 0 temporary */
static DWORD WINAPI VarBstrFromUI1 (VOID)
{
  return 0;
}


/* VarBstrFromUI2 ordinal = 230, argument = 0 temporary */
static DWORD WINAPI VarBstrFromUI2 (VOID)
{
  return 0;
}


/* VarBstrFromUI4 ordinal = 231, argument = 0 temporary */
static DWORD WINAPI VarBstrFromUI4 (VOID)
{
  return 0;
}


/* VarCat ordinal = 318, argument = 0 temporary */
static DWORD WINAPI VarCat (VOID)
{
  return 0;
}


/* VarCmp ordinal = 176, argument = 0 temporary */
static DWORD WINAPI VarCmp (VOID)
{
  return 0;
}


/* VarCyAbs ordinal = 306, argument = 0 temporary */
static DWORD WINAPI VarCyAbs (VOID)
{
  return 0;
}


/* VarCyAdd ordinal = 299, argument = 0 temporary */
static DWORD WINAPI VarCyAdd (VOID)
{
  return 0;
}


/* VarCyCmp ordinal = 311, argument = 0 temporary */
static DWORD WINAPI VarCyCmp (VOID)
{
  return 0;
}


/* VarCyCmpR8 ordinal = 312, argument = 0 temporary */
static DWORD WINAPI VarCyCmpR8 (VOID)
{
  return 0;
}


/* VarCyFix ordinal = 307, argument = 0 temporary */
static DWORD WINAPI VarCyFix (VOID)
{
  return 0;
}


/* VarCyFromBool ordinal = 106, argument = 0 temporary */
static DWORD WINAPI VarCyFromBool (VOID)
{
  return 0;
}


/* VarCyFromDate ordinal = 103, argument = 0 temporary */
static DWORD WINAPI VarCyFromDate (VOID)
{
  return 0;
}


/* VarCyFromDec ordinal = 228, argument = 0 temporary */
static DWORD WINAPI VarCyFromDec (VOID)
{
  return 0;
}


/* VarCyFromDisp ordinal = 105, argument = 0 temporary */
static DWORD WINAPI VarCyFromDisp (VOID)
{
  return 0;
}


/* VarCyFromI1 ordinal = 225, argument = 0 temporary */
static DWORD WINAPI VarCyFromI1 (VOID)
{
  return 0;
}


/* VarCyFromI2 ordinal = 99, argument = 0 temporary */
static DWORD WINAPI VarCyFromI2 (VOID)
{
  return 0;
}


/* VarCyFromI4 ordinal = 100, argument = 0 temporary */
static DWORD WINAPI VarCyFromI4 (VOID)
{
  return 0;
}


/* VarCyFromR4 ordinal = 101, argument = 0 temporary */
static DWORD WINAPI VarCyFromR4 (VOID)
{
  return 0;
}


/* VarCyFromR8 ordinal = 102, argument = 0 temporary */
static DWORD WINAPI VarCyFromR8 (VOID)
{
  return 0;
}


/* VarCyFromStr ordinal = 104, argument = 0 temporary */
static DWORD WINAPI VarCyFromStr (VOID)
{
  return 0;
}


/* VarCyFromUI1 ordinal = 98, argument = 0 temporary */
static DWORD WINAPI VarCyFromUI1 (VOID)
{
  return 0;
}


/* VarCyFromUI2 ordinal = 226, argument = 0 temporary */
static DWORD WINAPI VarCyFromUI2 (VOID)
{
  return 0;
}


/* VarCyFromUI4 ordinal = 227, argument = 0 temporary */
static DWORD WINAPI VarCyFromUI4 (VOID)
{
  return 0;
}


/* VarCyInt ordinal = 308, argument = 0 temporary */
static DWORD WINAPI VarCyInt (VOID)
{
  return 0;
}


/* VarCyMul ordinal = 303, argument = 0 temporary */
static DWORD WINAPI VarCyMul (VOID)
{
  return 0;
}


/* VarCyMulI4 ordinal = 304, argument = 0 temporary */
static DWORD WINAPI VarCyMulI4 (VOID)
{
  return 0;
}


/* VarCyNeg ordinal = 309, argument = 0 temporary */
static DWORD WINAPI VarCyNeg (VOID)
{
  return 0;
}


/* VarCyRound ordinal = 310, argument = 0 temporary */
static DWORD WINAPI VarCyRound (VOID)
{
  return 0;
}


/* VarCySub ordinal = 305, argument = 0 temporary */
static DWORD WINAPI VarCySub (VOID)
{
  return 0;
}


/* VarDateFromBool ordinal = 96, argument = 0 temporary */
static DWORD WINAPI VarDateFromBool (VOID)
{
  return 0;
}


/* VarDateFromCy ordinal = 93, argument = 0 temporary */
static DWORD WINAPI VarDateFromCy (VOID)
{
  return 0;
}


/* VarDateFromDec ordinal = 224, argument = 0 temporary */
static DWORD WINAPI VarDateFromDec (VOID)
{
  return 0;
}


/* VarDateFromDisp ordinal = 95, argument = 0 temporary */
static DWORD WINAPI VarDateFromDisp (VOID)
{
  return 0;
}


/* VarDateFromI1 ordinal = 221, argument = 0 temporary */
static DWORD WINAPI VarDateFromI1 (VOID)
{
  return 0;
}


/* VarDateFromI2 ordinal = 89, argument = 0 temporary */
static DWORD WINAPI VarDateFromI2 (VOID)
{
  return 0;
}


/* VarDateFromI4 ordinal = 90, argument = 0 temporary */
static DWORD WINAPI VarDateFromI4 (VOID)
{
  return 0;
}


/* VarDateFromR4 ordinal = 91, argument = 0 temporary */
static DWORD WINAPI VarDateFromR4 (VOID)
{
  return 0;
}


/* VarDateFromR8 ordinal = 92, argument = 0 temporary */
static DWORD WINAPI VarDateFromR8 (VOID)
{
  return 0;
}


/* VarDateFromStr ordinal = 94, argument = 0 temporary */
static DWORD WINAPI VarDateFromStr (VOID)
{
  return 0;
}


/* VarDateFromUI1 ordinal = 88, argument = 0 temporary */
static DWORD WINAPI VarDateFromUI1 (VOID)
{
  return 0;
}


/* VarDateFromUI2 ordinal = 222, argument = 0 temporary */
static DWORD WINAPI VarDateFromUI2 (VOID)
{
  return 0;
}


/* VarDateFromUI4 ordinal = 223, argument = 0 temporary */
static DWORD WINAPI VarDateFromUI4 (VOID)
{
  return 0;
}


/* VarDateFromUdate ordinal = 330, argument = 0 temporary */
static DWORD WINAPI VarDateFromUdate (VOID)
{
  return 0;
}


/* VarDateFromUdateEx ordinal = 319, argument = 0 temporary */
static DWORD WINAPI VarDateFromUdateEx (VOID)
{
  return 0;
}


/* VarDecAbs ordinal = 182, argument = 0 temporary */
static DWORD WINAPI VarDecAbs (VOID)
{
  return 0;
}


/* VarDecAdd ordinal = 177, argument = 0 temporary */
static DWORD WINAPI VarDecAdd (VOID)
{
  return 0;
}


/* VarDecCmp ordinal = 204, argument = 0 temporary */
static DWORD WINAPI VarDecCmp (VOID)
{
  return 0;
}


/* VarDecCmpR8 ordinal = 298, argument = 0 temporary */
static DWORD WINAPI VarDecCmpR8 (VOID)
{
  return 0;
}


/* VarDecDiv ordinal = 178, argument = 0 temporary */
static DWORD WINAPI VarDecDiv (VOID)
{
  return 0;
}


/* VarDecFix ordinal = 187, argument = 0 temporary */
static DWORD WINAPI VarDecFix (VOID)
{
  return 0;
}


/* VarDecFromBool ordinal = 199, argument = 0 temporary */
static DWORD WINAPI VarDecFromBool (VOID)
{
  return 0;
}


/* VarDecFromCy ordinal = 196, argument = 0 temporary */
static DWORD WINAPI VarDecFromCy (VOID)
{
  return 0;
}


/* VarDecFromDate ordinal = 195, argument = 0 temporary */
static DWORD WINAPI VarDecFromDate (VOID)
{
  return 0;
}


/* VarDecFromDisp ordinal = 198, argument = 0 temporary */
static DWORD WINAPI VarDecFromDisp (VOID)
{
  return 0;
}


/* VarDecFromI1 ordinal = 241, argument = 0 temporary */
static DWORD WINAPI VarDecFromI1 (VOID)
{
  return 0;
}


/* VarDecFromI2 ordinal = 191, argument = 0 temporary */
static DWORD WINAPI VarDecFromI2 (VOID)
{
  return 0;
}


/* VarDecFromI4 ordinal = 192, argument = 0 temporary */
static DWORD WINAPI VarDecFromI4 (VOID)
{
  return 0;
}


/* VarDecFromR4 ordinal = 193, argument = 0 temporary */
static DWORD WINAPI VarDecFromR4 (VOID)
{
  return 0;
}


/* VarDecFromR8 ordinal = 194, argument = 0 temporary */
static DWORD WINAPI VarDecFromR8 (VOID)
{
  return 0;
}


/* VarDecFromStr ordinal = 197, argument = 0 temporary */
static DWORD WINAPI VarDecFromStr (VOID)
{
  return 0;
}


/* VarDecFromUI1 ordinal = 190, argument = 0 temporary */
static DWORD WINAPI VarDecFromUI1 (VOID)
{
  return 0;
}


/* VarDecFromUI2 ordinal = 242, argument = 0 temporary */
static DWORD WINAPI VarDecFromUI2 (VOID)
{
  return 0;
}


/* VarDecFromUI4 ordinal = 243, argument = 0 temporary */
static DWORD WINAPI VarDecFromUI4 (VOID)
{
  return 0;
}


/* VarDecInt ordinal = 188, argument = 0 temporary */
static DWORD WINAPI VarDecInt (VOID)
{
  return 0;
}


/* VarDecMul ordinal = 179, argument = 0 temporary */
static DWORD WINAPI VarDecMul (VOID)
{
  return 0;
}


/* VarDecNeg ordinal = 189, argument = 0 temporary */
static DWORD WINAPI VarDecNeg (VOID)
{
  return 0;
}


/* VarDecRound ordinal = 203, argument = 0 temporary */
static DWORD WINAPI VarDecRound (VOID)
{
  return 0;
}


/* VarDecSub ordinal = 181, argument = 0 temporary */
static DWORD WINAPI VarDecSub (VOID)
{
  return 0;
}


/* VarDiv ordinal = 143, argument = 0 temporary */
static DWORD WINAPI VarDiv (VOID)
{
  return 0;
}


/* VarEqv ordinal = 152, argument = 0 temporary */
static DWORD WINAPI VarEqv (VOID)
{
  return 0;
}


/* VarFix ordinal = 169, argument = 0 temporary */
static DWORD WINAPI VarFix (VOID)
{
  return 0;
}


/* VarFormat ordinal = 87, argument = 0 temporary */
static DWORD WINAPI VarFormat (VOID)
{
  return 0;
}


/* VarFormatCurrency ordinal = 127, argument = 0 temporary */
static DWORD WINAPI VarFormatCurrency (VOID)
{
  return 0;
}


/* VarFormatDateTime ordinal = 97, argument = 0 temporary */
static DWORD WINAPI VarFormatDateTime (VOID)
{
  return 0;
}


/* VarFormatFromTokens ordinal = 139, argument = 0 temporary */
static DWORD WINAPI VarFormatFromTokens (VOID)
{
  return 0;
}


/* VarFormatNumber ordinal = 107, argument = 0 temporary */
static DWORD WINAPI VarFormatNumber (VOID)
{
  return 0;
}


/* VarFormatPercent ordinal = 117, argument = 0 temporary */
static DWORD WINAPI VarFormatPercent (VOID)
{
  return 0;
}


/* VarI1FromBool ordinal = 253, argument = 0 temporary */
static DWORD WINAPI VarI1FromBool (VOID)
{
  return 0;
}


/* VarI1FromCy ordinal = 250, argument = 0 temporary */
static DWORD WINAPI VarI1FromCy (VOID)
{
  return 0;
}


/* VarI1FromDate ordinal = 249, argument = 0 temporary */
static DWORD WINAPI VarI1FromDate (VOID)
{
  return 0;
}


/* VarI1FromDec ordinal = 256, argument = 0 temporary */
static DWORD WINAPI VarI1FromDec (VOID)
{
  return 0;
}


/* VarI1FromDisp ordinal = 252, argument = 0 temporary */
static DWORD WINAPI VarI1FromDisp (VOID)
{
  return 0;
}


/* VarI1FromI2 ordinal = 245, argument = 0 temporary */
static DWORD WINAPI VarI1FromI2 (VOID)
{
  return 0;
}


/* VarI1FromI4 ordinal = 246, argument = 0 temporary */
static DWORD WINAPI VarI1FromI4 (VOID)
{
  return 0;
}


/* VarI1FromR4 ordinal = 247, argument = 0 temporary */
static DWORD WINAPI VarI1FromR4 (VOID)
{
  return 0;
}


/* VarI1FromR8 ordinal = 248, argument = 0 temporary */
static DWORD WINAPI VarI1FromR8 (VOID)
{
  return 0;
}


/* VarI1FromStr ordinal = 251, argument = 0 temporary */
static DWORD WINAPI VarI1FromStr (VOID)
{
  return 0;
}


/* VarI1FromUI1 ordinal = 244, argument = 0 temporary */
static DWORD WINAPI VarI1FromUI1 (VOID)
{
  return 0;
}


/* VarI1FromUI2 ordinal = 254, argument = 0 temporary */
static DWORD WINAPI VarI1FromUI2 (VOID)
{
  return 0;
}


/* VarI1FromUI4 ordinal = 255, argument = 0 temporary */
static DWORD WINAPI VarI1FromUI4 (VOID)
{
  return 0;
}


/* VarI2FromBool ordinal = 56, argument = 0 temporary */
static DWORD WINAPI VarI2FromBool (VOID)
{
  return 0;
}


/* VarI2FromCy ordinal = 52, argument = 0 temporary */
static DWORD WINAPI VarI2FromCy (VOID)
{
  return 0;
}


/* VarI2FromDate ordinal = 53, argument = 0 temporary */
static DWORD WINAPI VarI2FromDate (VOID)
{
  return 0;
}


/* VarI2FromDec ordinal = 208, argument = 0 temporary */
static DWORD WINAPI VarI2FromDec (VOID)
{
  return 0;
}


/* VarI2FromDisp ordinal = 55, argument = 0 temporary */
static DWORD WINAPI VarI2FromDisp (VOID)
{
  return 0;
}


/* VarI2FromI1 ordinal = 205, argument = 0 temporary */
static DWORD WINAPI VarI2FromI1 (VOID)
{
  return 0;
}


/* VarI2FromI4 ordinal = 49, argument = 0 temporary */
static DWORD WINAPI VarI2FromI4 (VOID)
{
  return 0;
}


/* VarI2FromR4 ordinal = 50, argument = 0 temporary */
static DWORD WINAPI VarI2FromR4 (VOID)
{
  return 0;
}


/* VarI2FromR8 ordinal = 51, argument = 0 temporary */
static DWORD WINAPI VarI2FromR8 (VOID)
{
  return 0;
}


/* VarI2FromStr ordinal = 54, argument = 0 temporary */
static DWORD WINAPI VarI2FromStr (VOID)
{
  return 0;
}


/* VarI2FromUI1 ordinal = 48, argument = 0 temporary */
static DWORD WINAPI VarI2FromUI1 (VOID)
{
  return 0;
}


/* VarI2FromUI2 ordinal = 206, argument = 0 temporary */
static DWORD WINAPI VarI2FromUI2 (VOID)
{
  return 0;
}


/* VarI2FromUI4 ordinal = 207, argument = 0 temporary */
static DWORD WINAPI VarI2FromUI4 (VOID)
{
  return 0;
}


/* VarI4FromBool ordinal = 66, argument = 0 temporary */
static DWORD WINAPI VarI4FromBool (VOID)
{
  return 0;
}


/* VarI4FromCy ordinal = 62, argument = 0 temporary */
static DWORD WINAPI VarI4FromCy (VOID)
{
  return 0;
}


/* VarI4FromDate ordinal = 63, argument = 0 temporary */
static DWORD WINAPI VarI4FromDate (VOID)
{
  return 0;
}


/* VarI4FromDec ordinal = 212, argument = 0 temporary */
static DWORD WINAPI VarI4FromDec (VOID)
{
  return 0;
}


/* VarI4FromDisp ordinal = 65, argument = 0 temporary */
static DWORD WINAPI VarI4FromDisp (VOID)
{
  return 0;
}


/* VarI4FromI1 ordinal = 209, argument = 0 temporary */
static DWORD WINAPI VarI4FromI1 (VOID)
{
  return 0;
}


/* VarI4FromI2 ordinal = 59, argument = 0 temporary */
static DWORD WINAPI VarI4FromI2 (VOID)
{
  return 0;
}


/* VarI4FromR4 ordinal = 60, argument = 0 temporary */
static DWORD WINAPI VarI4FromR4 (VOID)
{
  return 0;
}


/* VarI4FromR8 ordinal = 61, argument = 0 temporary */
static DWORD WINAPI VarI4FromR8 (VOID)
{
  return 0;
}


/* VarI4FromStr ordinal = 64, argument = 0 temporary */
static DWORD WINAPI VarI4FromStr (VOID)
{
  return 0;
}


/* VarI4FromUI1 ordinal = 58, argument = 0 temporary */
static DWORD WINAPI VarI4FromUI1 (VOID)
{
  return 0;
}


/* VarI4FromUI2 ordinal = 210, argument = 0 temporary */
static DWORD WINAPI VarI4FromUI2 (VOID)
{
  return 0;
}


/* VarI4FromUI4 ordinal = 211, argument = 0 temporary */
static DWORD WINAPI VarI4FromUI4 (VOID)
{
  return 0;
}


/* VarIdiv ordinal = 153, argument = 0 temporary */
static DWORD WINAPI VarIdiv (VOID)
{
  return 0;
}


/* VarImp ordinal = 154, argument = 0 temporary */
static DWORD WINAPI VarImp (VOID)
{
  return 0;
}


/* VarInt ordinal = 172, argument = 0 temporary */
static DWORD WINAPI VarInt (VOID)
{
  return 0;
}


/* VarMod ordinal = 155, argument = 0 temporary */
static DWORD WINAPI VarMod (VOID)
{
  return 0;
}


/* VarMonthName ordinal = 129, argument = 0 temporary */
static DWORD WINAPI VarMonthName (VOID)
{
  return 0;
}


/* VarMul ordinal = 156, argument = 0 temporary */
static DWORD WINAPI VarMul (VOID)
{
  return 0;
}


/* VarNeg ordinal = 173, argument = 0 temporary */
static DWORD WINAPI VarNeg (VOID)
{
  return 0;
}


/* VarNot ordinal = 174, argument = 0 temporary */
static DWORD WINAPI VarNot (VOID)
{
  return 0;
}


/* VarNumFromParseNum ordinal = 47, argument = 0 temporary */
static DWORD WINAPI VarNumFromParseNum (VOID)
{
  return 0;
}


/* VarOr ordinal = 157, argument = 0 temporary */
static DWORD WINAPI VarOr (VOID)
{
  return 0;
}


/* VarParseNumFromStr ordinal = 46, argument = 0 temporary */
static DWORD WINAPI VarParseNumFromStr (VOID)
{
  return 0;
}


/* VarPow ordinal = 158, argument = 0 temporary */
static DWORD WINAPI VarPow (VOID)
{
  return 0;
}


/* VarR4CmpR8 ordinal = 316, argument = 0 temporary */
static DWORD WINAPI VarR4CmpR8 (VOID)
{
  return 0;
}


/* VarR4FromBool ordinal = 76, argument = 0 temporary */
static DWORD WINAPI VarR4FromBool (VOID)
{
  return 0;
}


/* VarR4FromCy ordinal = 72, argument = 0 temporary */
static DWORD WINAPI VarR4FromCy (VOID)
{
  return 0;
}


/* VarR4FromDate ordinal = 73, argument = 0 temporary */
static DWORD WINAPI VarR4FromDate (VOID)
{
  return 0;
}


/* VarR4FromDec ordinal = 216, argument = 0 temporary */
static DWORD WINAPI VarR4FromDec (VOID)
{
  return 0;
}


/* VarR4FromDisp ordinal = 75, argument = 0 temporary */
static DWORD WINAPI VarR4FromDisp (VOID)
{
  return 0;
}


/* VarR4FromI1 ordinal = 213, argument = 0 temporary */
static DWORD WINAPI VarR4FromI1 (VOID)
{
  return 0;
}


/* VarR4FromI2 ordinal = 69, argument = 0 temporary */
static DWORD WINAPI VarR4FromI2 (VOID)
{
  return 0;
}


/* VarR4FromI4 ordinal = 70, argument = 0 temporary */
static DWORD WINAPI VarR4FromI4 (VOID)
{
  return 0;
}


/* VarR4FromR8 ordinal = 71, argument = 0 temporary */
static DWORD WINAPI VarR4FromR8 (VOID)
{
  return 0;
}


/* VarR4FromStr ordinal = 74, argument = 0 temporary */
static DWORD WINAPI VarR4FromStr (VOID)
{
  return 0;
}


/* VarR4FromUI1 ordinal = 68, argument = 0 temporary */
static DWORD WINAPI VarR4FromUI1 (VOID)
{
  return 0;
}


/* VarR4FromUI2 ordinal = 214, argument = 0 temporary */
static DWORD WINAPI VarR4FromUI2 (VOID)
{
  return 0;
}


/* VarR4FromUI4 ordinal = 215, argument = 0 temporary */
static DWORD WINAPI VarR4FromUI4 (VOID)
{
  return 0;
}


/* VarR8FromBool ordinal = 86, argument = 0 temporary */
static DWORD WINAPI VarR8FromBool (VOID)
{
  return 0;
}


/* VarR8FromCy ordinal = 82, argument = 0 temporary */
static DWORD WINAPI VarR8FromCy (VOID)
{
  return 0;
}


/* VarR8FromDate ordinal = 83, argument = 0 temporary */
static DWORD WINAPI VarR8FromDate (VOID)
{
  return 0;
}


/* VarR8FromDec ordinal = 220, argument = 0 temporary */
static DWORD WINAPI VarR8FromDec (VOID)
{
  return 0;
}


/* VarR8FromDisp ordinal = 85, argument = 0 temporary */
static DWORD WINAPI VarR8FromDisp (VOID)
{
  return 0;
}


/* VarR8FromI1 ordinal = 217, argument = 0 temporary */
static DWORD WINAPI VarR8FromI1 (VOID)
{
  return 0;
}


/* VarR8FromI2 ordinal = 79, argument = 0 temporary */
static DWORD WINAPI VarR8FromI2 (VOID)
{
  return 0;
}


/* VarR8FromI4 ordinal = 80, argument = 0 temporary */
static DWORD WINAPI VarR8FromI4 (VOID)
{
  return 0;
}


/* VarR8FromR4 ordinal = 81, argument = 0 temporary */
static DWORD WINAPI VarR8FromR4 (VOID)
{
  return 0;
}


/* VarR8FromStr ordinal = 84, argument = 0 temporary */
static DWORD WINAPI VarR8FromStr (VOID)
{
  return 0;
}


/* VarR8FromUI1 ordinal = 78, argument = 0 temporary */
static DWORD WINAPI VarR8FromUI1 (VOID)
{
  return 0;
}


/* VarR8FromUI2 ordinal = 218, argument = 0 temporary */
static DWORD WINAPI VarR8FromUI2 (VOID)
{
  return 0;
}


/* VarR8FromUI4 ordinal = 219, argument = 0 temporary */
static DWORD WINAPI VarR8FromUI4 (VOID)
{
  return 0;
}


/* VarR8Pow ordinal = 315, argument = 0 temporary */
static DWORD WINAPI VarR8Pow (VOID)
{
  return 0;
}


/* VarR8Round ordinal = 317, argument = 0 temporary */
static DWORD WINAPI VarR8Round (VOID)
{
  return 0;
}


/* VarRound ordinal = 175, argument = 0 temporary */
static DWORD WINAPI VarRound (VOID)
{
  return 0;
}


/* VarSub ordinal = 159, argument = 0 temporary */
static DWORD WINAPI VarSub (VOID)
{
  return 0;
}


/* VarTokenizeFormatString ordinal = 140, argument = 0 temporary */
static DWORD WINAPI VarTokenizeFormatString (VOID)
{
  return 0;
}


/* VarUI1FromBool ordinal = 138, argument = 0 temporary */
static DWORD WINAPI VarUI1FromBool (VOID)
{
  return 0;
}


/* VarUI1FromCy ordinal = 134, argument = 0 temporary */
static DWORD WINAPI VarUI1FromCy (VOID)
{
  return 0;
}


/* VarUI1FromDate ordinal = 135, argument = 0 temporary */
static DWORD WINAPI VarUI1FromDate (VOID)
{
  return 0;
}


/* VarUI1FromDec ordinal = 240, argument = 0 temporary */
static DWORD WINAPI VarUI1FromDec (VOID)
{
  return 0;
}


/* VarUI1FromDisp ordinal = 137, argument = 0 temporary */
static DWORD WINAPI VarUI1FromDisp (VOID)
{
  return 0;
}


/* VarUI1FromI1 ordinal = 237, argument = 0 temporary */
static DWORD WINAPI VarUI1FromI1 (VOID)
{
  return 0;
}


/* VarUI1FromI2 ordinal = 130, argument = 0 temporary */
static DWORD WINAPI VarUI1FromI2 (VOID)
{
  return 0;
}


/* VarUI1FromI4 ordinal = 131, argument = 0 temporary */
static DWORD WINAPI VarUI1FromI4 (VOID)
{
  return 0;
}


/* VarUI1FromR4 ordinal = 132, argument = 0 temporary */
static DWORD WINAPI VarUI1FromR4 (VOID)
{
  return 0;
}


/* VarUI1FromR8 ordinal = 133, argument = 0 temporary */
static DWORD WINAPI VarUI1FromR8 (VOID)
{
  return 0;
}


/* VarUI1FromStr ordinal = 136, argument = 0 temporary */
static DWORD WINAPI VarUI1FromStr (VOID)
{
  return 0;
}


/* VarUI1FromUI2 ordinal = 238, argument = 0 temporary */
static DWORD WINAPI VarUI1FromUI2 (VOID)
{
  return 0;
}


/* VarUI1FromUI4 ordinal = 239, argument = 0 temporary */
static DWORD WINAPI VarUI1FromUI4 (VOID)
{
  return 0;
}


/* VarUI2FromBool ordinal = 266, argument = 0 temporary */
static DWORD WINAPI VarUI2FromBool (VOID)
{
  return 0;
}


/* VarUI2FromCy ordinal = 263, argument = 0 temporary */
static DWORD WINAPI VarUI2FromCy (VOID)
{
  return 0;
}


/* VarUI2FromDate ordinal = 262, argument = 0 temporary */
static DWORD WINAPI VarUI2FromDate (VOID)
{
  return 0;
}


/* VarUI2FromDec ordinal = 269, argument = 0 temporary */
static DWORD WINAPI VarUI2FromDec (VOID)
{
  return 0;
}


/* VarUI2FromDisp ordinal = 265, argument = 0 temporary */
static DWORD WINAPI VarUI2FromDisp (VOID)
{
  return 0;
}


/* VarUI2FromI1 ordinal = 267, argument = 0 temporary */
static DWORD WINAPI VarUI2FromI1 (VOID)
{
  return 0;
}


/* VarUI2FromI2 ordinal = 258, argument = 0 temporary */
static DWORD WINAPI VarUI2FromI2 (VOID)
{
  return 0;
}


/* VarUI2FromI4 ordinal = 259, argument = 0 temporary */
static DWORD WINAPI VarUI2FromI4 (VOID)
{
  return 0;
}


/* VarUI2FromR4 ordinal = 260, argument = 0 temporary */
static DWORD WINAPI VarUI2FromR4 (VOID)
{
  return 0;
}


/* VarUI2FromR8 ordinal = 261, argument = 0 temporary */
static DWORD WINAPI VarUI2FromR8 (VOID)
{
  return 0;
}


/* VarUI2FromStr ordinal = 264, argument = 0 temporary */
static DWORD WINAPI VarUI2FromStr (VOID)
{
  return 0;
}


/* VarUI2FromUI1 ordinal = 257, argument = 0 temporary */
static DWORD WINAPI VarUI2FromUI1 (VOID)
{
  return 0;
}


/* VarUI2FromUI4 ordinal = 268, argument = 0 temporary */
static DWORD WINAPI VarUI2FromUI4 (VOID)
{
  return 0;
}


/* VarUI4FromBool ordinal = 279, argument = 0 temporary */
static DWORD WINAPI VarUI4FromBool (VOID)
{
  return 0;
}


/* VarUI4FromCy ordinal = 276, argument = 0 temporary */
static DWORD WINAPI VarUI4FromCy (VOID)
{
  return 0;
}


/* VarUI4FromDate ordinal = 275, argument = 0 temporary */
static DWORD WINAPI VarUI4FromDate (VOID)
{
  return 0;
}


/* VarUI4FromDec ordinal = 282, argument = 0 temporary */
static DWORD WINAPI VarUI4FromDec (VOID)
{
  return 0;
}


/* VarUI4FromDisp ordinal = 278, argument = 0 temporary */
static DWORD WINAPI VarUI4FromDisp (VOID)
{
  return 0;
}


/* VarUI4FromI1 ordinal = 280, argument = 0 temporary */
static DWORD WINAPI VarUI4FromI1 (VOID)
{
  return 0;
}


/* VarUI4FromI2 ordinal = 271, argument = 0 temporary */
static DWORD WINAPI VarUI4FromI2 (VOID)
{
  return 0;
}


/* VarUI4FromI4 ordinal = 272, argument = 0 temporary */
static DWORD WINAPI VarUI4FromI4 (VOID)
{
  return 0;
}


/* VarUI4FromR4 ordinal = 273, argument = 0 temporary */
static DWORD WINAPI VarUI4FromR4 (VOID)
{
  return 0;
}


/* VarUI4FromR8 ordinal = 274, argument = 0 temporary */
static DWORD WINAPI VarUI4FromR8 (VOID)
{
  return 0;
}


/* VarUI4FromStr ordinal = 277, argument = 0 temporary */
static DWORD WINAPI VarUI4FromStr (VOID)
{
  return 0;
}


/* VarUI4FromUI1 ordinal = 270, argument = 0 temporary */
static DWORD WINAPI VarUI4FromUI1 (VOID)
{
  return 0;
}


/* VarUI4FromUI2 ordinal = 281, argument = 0 temporary */
static DWORD WINAPI VarUI4FromUI2 (VOID)
{
  return 0;
}


/* VarUdateFromDate ordinal = 331, argument = 0 temporary */
static DWORD WINAPI VarUdateFromDate (VOID)
{
  return 0;
}


/* VarWeekdayName ordinal = 128, argument = 0 temporary */
static DWORD WINAPI VarWeekdayName (VOID)
{
  return 0;
}


/* VarXor ordinal = 167, argument = 0 temporary */
static DWORD WINAPI VarXor (VOID)
{
  return 0;
}


/* VariantChangeType ordinal = 12, argument = 0 temporary */
static DWORD WINAPI VariantChangeType (VOID)
{
  return 0;
}


/* VariantChangeTypeEx ordinal = 147, argument = 0 temporary */
static DWORD WINAPI VariantChangeTypeEx (VOID)
{
  return 0;
}


/* VariantClear ordinal = 9, argument = 0 temporary */
static DWORD WINAPI VariantClear (VOID)
{
  return 0;
}


/* VariantCopy ordinal = 10, argument = 0 temporary */
static DWORD WINAPI VariantCopy (VOID)
{
  return 0;
}


/* VariantCopyInd ordinal = 11, argument = 0 temporary */
static DWORD WINAPI VariantCopyInd (VOID)
{
  return 0;
}


/* VariantInit ordinal = 8, argument = 0 temporary */
static DWORD WINAPI VariantInit (VOID)
{
  return 0;
}


/* VariantTimeToDosDateTime ordinal = 13, argument = 0 temporary */
static DWORD WINAPI VariantTimeToDosDateTime (VOID)
{
  return 0;
}


/* VariantTimeToSystemTime ordinal = 185, argument = 0 temporary */
static DWORD WINAPI VariantTimeToSystemTime (VOID)
{
  return 0;
}


/* VectorFromBstr ordinal = 413, argument = 0 temporary */
static DWORD WINAPI VectorFromBstr (VOID)
{
  return 0;
}


W32LdrExport oleaut32_exports[] = {
{FALSE, 286, "BSTR_UserFree",                  BSTR_UserFree},
{FALSE, 284, "BSTR_UserMarshal",               BSTR_UserMarshal},
{FALSE, 283, "BSTR_UserSize",                  BSTR_UserSize},
{FALSE, 285, "BSTR_UserUnmarshal",             BSTR_UserUnmarshal},
{FALSE, 414, "BstrFromVector",                 BstrFromVector},
{FALSE, 171, "ClearCustData",                  ClearCustData},
{FALSE,  31, "CreateDispTypeInfo",             CreateDispTypeInfo},
{FALSE, 202, "CreateErrorInfo",                CreateErrorInfo},
{FALSE,  32, "CreateStdDispatch",              CreateStdDispatch},
{FALSE, 160, "CreateTypeLib",                  CreateTypeLib},
{FALSE, 180, "CreateTypeLib2",                 CreateTypeLib2},
{FALSE, 146, "DispCallFunc",                   DispCallFunc},
{FALSE,  29, "DispGetIDsOfNames",              DispGetIDsOfNames},
{FALSE,  28, "DispGetParam",                   DispGetParam},
{FALSE,  30, "DispInvoke",                     DispInvoke},
{FALSE, 410, "DllCanUnloadNow",                DllCanUnloadNow},
{FALSE,   1, "DllGetClassObject",              DllGetClassObject},
{FALSE, 320, "DllRegisterServer",              DllRegisterServer},
{FALSE, 321, "DllUnregisterServer",            DllUnregisterServer},
{FALSE,  14, "DosDateTimeToVariantTime",       DosDateTimeToVariantTime},
{FALSE,  35, "GetActiveObject",                GetActiveObject},
{FALSE, 332, "GetAltMonthNames",               GetAltMonthNames},
{FALSE, 200, "GetErrorInfo",                   GetErrorInfo},
{FALSE, 322, "GetRecordInfoFromGuids",         GetRecordInfoFromGuids},
{FALSE, 323, "GetRecordInfoFromTypeInfo",      GetRecordInfoFromTypeInfo},
{FALSE, 326, "GetVarConversionLocaleSetting",  GetVarConversionLocaleSetting},
{FALSE, 165, "LHashValOfNameSys",              LHashValOfNameSysA},
{FALSE, 166, "LHashValOfNameSysA",             LHashValOfNameSysA},
{FALSE, 296, "LPSAFEARRAY_Marshal",            LPSAFEARRAY_Marshal},
{FALSE, 295, "LPSAFEARRAY_Size",               LPSAFEARRAY_Size},
{FALSE, 297, "LPSAFEARRAY_Unmarshal",          LPSAFEARRAY_Unmarshal},
{FALSE, 294, "LPSAFEARRAY_UserFree",           LPSAFEARRAY_UserFree},
{FALSE, 292, "LPSAFEARRAY_UserMarshal",        LPSAFEARRAY_UserMarshal},
{FALSE, 291, "LPSAFEARRAY_UserSize",           LPSAFEARRAY_UserSize},
{FALSE, 293, "LPSAFEARRAY_UserUnmarshal",      LPSAFEARRAY_UserUnmarshal},
{FALSE, 162, "LoadRegTypeLib",                 LoadRegTypeLib},
{TRUE,  161, "LoadTypeLib",                    LoadTypeLib},
{TRUE,  183, "LoadTypeLibEx",                  LoadTypeLibEx},
{FALSE, 144, "OACreateTypeLib2",               OACreateTypeLib2},
{FALSE, 170, "OaBuildVersion",                 OaBuildVersion},
{FALSE, 420, "OleCreateFontIndirect",          OleCreateFontIndirect},
{FALSE, 419, "OleCreatePictureIndirect",       OleCreatePictureIndirect},
{FALSE, 417, "OleCreatePropertyFrame",         OleCreatePropertyFrame},
{FALSE, 416, "OleCreatePropertyFrameIndirect", OleCreatePropertyFrameIndirect},
{FALSE, 415, "OleIconToCursor",                OleIconToCursor},
{FALSE, 418, "OleLoadPicture",                 OleLoadPicture},
{FALSE, 401, "OleLoadPictureEx",               OleLoadPictureEx},
{FALSE, 422, "OleLoadPictureFile",             OleLoadPictureFile},
{FALSE, 402, "OleLoadPictureFileEx",           OleLoadPictureFileEx},
{FALSE, 424, "OleLoadPicturePath",             OleLoadPicturePath},
{FALSE, 423, "OleSavePictureFile",             OleSavePictureFile},
{FALSE, 421, "OleTranslateColor",              OleTranslateColor},
{FALSE, 164, "QueryPathOfRegTypeLib",          QueryPathOfRegTypeLib},
{FALSE,  33, "RegisterActiveObject",           RegisterActiveObject},
{TRUE,  163, "RegisterTypeLib",                RegisterTypeLib},
{FALSE,  34, "RevokeActiveObject",             RevokeActiveObject},
{FALSE,  23, "SafeArrayAccessData",            SafeArrayAccessData},
{FALSE,  37, "SafeArrayAllocData",             SafeArrayAllocData},
{FALSE,  36, "SafeArrayAllocDescriptor",       SafeArrayAllocDescriptor},
{FALSE,  41, "SafeArrayAllocDescriptorEx",     SafeArrayAllocDescriptorEx},
{FALSE,  27, "SafeArrayCopy",                  SafeArrayCopy},
{FALSE, 412, "SafeArrayCopyData",              SafeArrayCopyData},
{FALSE,  15, "SafeArrayCreate",                SafeArrayCreate},
{FALSE,  42, "SafeArrayCreateEx",              SafeArrayCreateEx},
{FALSE, 411, "SafeArrayCreateVector",          SafeArrayCreateVector},
{FALSE,  43, "SafeArrayCreateVectorEx",        SafeArrayCreateVectorEx},
{FALSE,  16, "SafeArrayDestroy",               SafeArrayDestroy},
{FALSE,  39, "SafeArrayDestroyData",           SafeArrayDestroyData},
{FALSE,  38, "SafeArrayDestroyDescriptor",     SafeArrayDestroyDescriptor},
{FALSE,  17, "SafeArrayGetDim",                SafeArrayGetDim},
{FALSE,  25, "SafeArrayGetElement",            SafeArrayGetElement},
{FALSE,  18, "SafeArrayGetElemsize",           SafeArrayGetElemsize},
{FALSE,  67, "SafeArrayGetIID",                SafeArrayGetIID},
{FALSE,  20, "SafeArrayGetLBound",             SafeArrayGetLBound},
{FALSE,  45, "SafeArrayGetRecordInfo",         SafeArrayGetRecordInfo},
{FALSE,  19, "SafeArrayGetUBound",             SafeArrayGetUBound},
{FALSE,  77, "SafeArrayGetVartype",            SafeArrayGetVartype},
{FALSE,  21, "SafeArrayLock",                  SafeArrayLock},
{FALSE, 148, "SafeArrayPtrOfIndex",            SafeArrayPtrOfIndex},
{FALSE,  26, "SafeArrayPutElement",            SafeArrayPutElement},
{FALSE,  40, "SafeArrayRedim",                 SafeArrayRedim},
{FALSE,  57, "SafeArraySetIID",                SafeArraySetIID},
{FALSE,  44, "SafeArraySetRecordInfo",         SafeArraySetRecordInfo},
{FALSE,  24, "SafeArrayUnaccessData",          SafeArrayUnaccessData},
{FALSE,  22, "SafeArrayUnlock",                SafeArrayUnlock},
{FALSE, 201, "SetErrorInfo",                   SetErrorInfo},
{FALSE, 325, "SetVarConversionLocaleSetting",  SetVarConversionLocaleSetting},
{FALSE,   2, "SysAllocString",                 SysAllocString},
{FALSE, 150, "SysAllocStringByteLen",          SysAllocStringByteLen},
{FALSE,   4, "SysAllocStringLen",              SysAllocStringLen},
{FALSE,   6, "SysFreeString",                  SysFreeString},
{FALSE,   3, "SysReAllocString",               SysReAllocString},
{FALSE,   5, "SysReAllocStringLen",            SysReAllocStringLen},
{FALSE, 149, "SysStringByteLen",               SysStringByteLen},
{FALSE,   7, "SysStringLen",                   SysStringLen},
{FALSE, 184, "SystemTimeToVariantTime",        SystemTimeToVariantTime},
{FALSE, 186, "UnRegisterTypeLib",              UnRegisterTypeLib},
{FALSE, 386, "UserBSTR_free_inst",             UserBSTR_free_inst},
{FALSE, 387, "UserBSTR_free_local",            UserBSTR_free_local},
{FALSE, 384, "UserBSTR_from_local",            UserBSTR_from_local},
{FALSE, 385, "UserBSTR_to_local",              UserBSTR_to_local},
{FALSE, 394, "UserEXCEPINFO_free_inst",        UserEXCEPINFO_free_inst},
{FALSE, 395, "UserEXCEPINFO_free_local",       UserEXCEPINFO_free_local},
{FALSE, 392, "UserEXCEPINFO_from_local",       UserEXCEPINFO_from_local},
{FALSE, 393, "UserEXCEPINFO_to_local",         UserEXCEPINFO_to_local},
{FALSE, 382, "UserHWND_free_inst",             UserHWND_free_inst},
{FALSE, 383, "UserHWND_free_local",            UserHWND_free_local},
{FALSE, 380, "UserHWND_from_local",            UserHWND_from_local},
{FALSE, 381, "UserHWND_to_local",              UserHWND_to_local},
{FALSE, 398, "UserMSG_free_inst",              UserMSG_free_inst},
{FALSE, 399, "UserMSG_free_local",             UserMSG_free_local},
{FALSE, 396, "UserMSG_from_local",             UserMSG_from_local},
{FALSE, 397, "UserMSG_to_local",               UserMSG_to_local},
{FALSE, 390, "UserVARIANT_free_inst",          UserVARIANT_free_inst},
{FALSE, 391, "UserVARIANT_free_local",         UserVARIANT_free_local},
{FALSE, 388, "UserVARIANT_from_local",         UserVARIANT_from_local},
{FALSE, 389, "UserVARIANT_to_local",           UserVARIANT_to_local},
{FALSE, 290, "VARIANT_UserFree",               VARIANT_UserFree},
{FALSE, 288, "VARIANT_UserMarshal",            VARIANT_UserMarshal},
{FALSE, 287, "VARIANT_UserSize",               VARIANT_UserSize},
{FALSE, 289, "VARIANT_UserUnmarshal",          VARIANT_UserUnmarshal},
{FALSE, 168, "VarAbs",                         VarAbs},
{FALSE, 141, "VarAdd",                         VarAdd},
{FALSE, 142, "VarAnd",                         VarAnd},
{FALSE, 124, "VarBoolFromCy",                  VarBoolFromCy},
{FALSE, 123, "VarBoolFromDate",                VarBoolFromDate},
{FALSE, 236, "VarBoolFromDec",                 VarBoolFromDec},
{FALSE, 126, "VarBoolFromDisp",                VarBoolFromDisp},
{FALSE, 233, "VarBoolFromI1",                  VarBoolFromI1},
{FALSE, 119, "VarBoolFromI2",                  VarBoolFromI2},
{FALSE, 120, "VarBoolFromI4",                  VarBoolFromI4},
{FALSE, 121, "VarBoolFromR4",                  VarBoolFromR4},
{FALSE, 122, "VarBoolFromR8",                  VarBoolFromR8},
{FALSE, 125, "VarBoolFromStr",                 VarBoolFromStr},
{FALSE, 118, "VarBoolFromUI1",                 VarBoolFromUI1},
{FALSE, 234, "VarBoolFromUI2",                 VarBoolFromUI2},
{FALSE, 235, "VarBoolFromUI4",                 VarBoolFromUI4},
{FALSE, 313, "VarBstrCat",                     VarBstrCat},
{FALSE, 314, "VarBstrCmp",                     VarBstrCmp},
{FALSE, 116, "VarBstrFromBool",                VarBstrFromBool},
{FALSE, 113, "VarBstrFromCy",                  VarBstrFromCy},
{FALSE, 114, "VarBstrFromDate",                VarBstrFromDate},
{FALSE, 232, "VarBstrFromDec",                 VarBstrFromDec},
{FALSE, 115, "VarBstrFromDisp",                VarBstrFromDisp},
{FALSE, 229, "VarBstrFromI1",                  VarBstrFromI1},
{FALSE, 109, "VarBstrFromI2",                  VarBstrFromI2},
{FALSE, 110, "VarBstrFromI4",                  VarBstrFromI4},
{FALSE, 111, "VarBstrFromR4",                  VarBstrFromR4},
{FALSE, 112, "VarBstrFromR8",                  VarBstrFromR8},
{FALSE, 108, "VarBstrFromUI1",                 VarBstrFromUI1},
{FALSE, 230, "VarBstrFromUI2",                 VarBstrFromUI2},
{FALSE, 231, "VarBstrFromUI4",                 VarBstrFromUI4},
{FALSE, 318, "VarCat",                         VarCat},
{FALSE, 176, "VarCmp",                         VarCmp},
{FALSE, 306, "VarCyAbs",                       VarCyAbs},
{FALSE, 299, "VarCyAdd",                       VarCyAdd},
{FALSE, 311, "VarCyCmp",                       VarCyCmp},
{FALSE, 312, "VarCyCmpR8",                     VarCyCmpR8},
{FALSE, 307, "VarCyFix",                       VarCyFix},
{FALSE, 106, "VarCyFromBool",                  VarCyFromBool},
{FALSE, 103, "VarCyFromDate",                  VarCyFromDate},
{FALSE, 228, "VarCyFromDec",                   VarCyFromDec},
{FALSE, 105, "VarCyFromDisp",                  VarCyFromDisp},
{FALSE, 225, "VarCyFromI1",                    VarCyFromI1},
{FALSE,  99, "VarCyFromI2",                    VarCyFromI2},
{FALSE, 100, "VarCyFromI4",                    VarCyFromI4},
{FALSE, 101, "VarCyFromR4",                    VarCyFromR4},
{FALSE, 102, "VarCyFromR8",                    VarCyFromR8},
{FALSE, 104, "VarCyFromStr",                   VarCyFromStr},
{FALSE,  98, "VarCyFromUI1",                   VarCyFromUI1},
{FALSE, 226, "VarCyFromUI2",                   VarCyFromUI2},
{FALSE, 227, "VarCyFromUI4",                   VarCyFromUI4},
{FALSE, 308, "VarCyInt",                       VarCyInt},
{FALSE, 303, "VarCyMul",                       VarCyMul},
{FALSE, 304, "VarCyMulI4",                     VarCyMulI4},
{FALSE, 309, "VarCyNeg",                       VarCyNeg},
{FALSE, 310, "VarCyRound",                     VarCyRound},
{FALSE, 305, "VarCySub",                       VarCySub},
{FALSE,  96, "VarDateFromBool",                VarDateFromBool},
{FALSE,  93, "VarDateFromCy",                  VarDateFromCy},
{FALSE, 224, "VarDateFromDec",                 VarDateFromDec},
{FALSE,  95, "VarDateFromDisp",                VarDateFromDisp},
{FALSE, 221, "VarDateFromI1",                  VarDateFromI1},
{FALSE,  89, "VarDateFromI2",                  VarDateFromI2},
{FALSE,  90, "VarDateFromI4",                  VarDateFromI4},
{FALSE,  91, "VarDateFromR4",                  VarDateFromR4},
{FALSE,  92, "VarDateFromR8",                  VarDateFromR8},
{FALSE,  94, "VarDateFromStr",                 VarDateFromStr},
{FALSE,  88, "VarDateFromUI1",                 VarDateFromUI1},
{FALSE, 222, "VarDateFromUI2",                 VarDateFromUI2},
{FALSE, 223, "VarDateFromUI4",                 VarDateFromUI4},
{FALSE, 330, "VarDateFromUdate",               VarDateFromUdate},
{FALSE, 319, "VarDateFromUdateEx",             VarDateFromUdateEx},
{FALSE, 182, "VarDecAbs",                      VarDecAbs},
{FALSE, 177, "VarDecAdd",                      VarDecAdd},
{FALSE, 204, "VarDecCmp",                      VarDecCmp},
{FALSE, 298, "VarDecCmpR8",                    VarDecCmpR8},
{FALSE, 178, "VarDecDiv",                      VarDecDiv},
{FALSE, 187, "VarDecFix",                      VarDecFix},
{FALSE, 199, "VarDecFromBool",                 VarDecFromBool},
{FALSE, 196, "VarDecFromCy",                   VarDecFromCy},
{FALSE, 195, "VarDecFromDate",                 VarDecFromDate},
{FALSE, 198, "VarDecFromDisp",                 VarDecFromDisp},
{FALSE, 241, "VarDecFromI1",                   VarDecFromI1},
{FALSE, 191, "VarDecFromI2",                   VarDecFromI2},
{FALSE, 192, "VarDecFromI4",                   VarDecFromI4},
{FALSE, 193, "VarDecFromR4",                   VarDecFromR4},
{FALSE, 194, "VarDecFromR8",                   VarDecFromR8},
{FALSE, 197, "VarDecFromStr",                  VarDecFromStr},
{FALSE, 190, "VarDecFromUI1",                  VarDecFromUI1},
{FALSE, 242, "VarDecFromUI2",                  VarDecFromUI2},
{FALSE, 243, "VarDecFromUI4",                  VarDecFromUI4},
{FALSE, 188, "VarDecInt",                      VarDecInt},
{FALSE, 179, "VarDecMul",                      VarDecMul},
{FALSE, 189, "VarDecNeg",                      VarDecNeg},
{FALSE, 203, "VarDecRound",                    VarDecRound},
{FALSE, 181, "VarDecSub",                      VarDecSub},
{FALSE, 143, "VarDiv",                         VarDiv},
{FALSE, 152, "VarEqv",                         VarEqv},
{FALSE, 169, "VarFix",                         VarFix},
{FALSE,  87, "VarFormat",                      VarFormat},
{FALSE, 127, "VarFormatCurrency",              VarFormatCurrency},
{FALSE,  97, "VarFormatDateTime",              VarFormatDateTime},
{FALSE, 139, "VarFormatFromTokens",            VarFormatFromTokens},
{FALSE, 107, "VarFormatNumber",                VarFormatNumber},
{FALSE, 117, "VarFormatPercent",               VarFormatPercent},
{FALSE, 253, "VarI1FromBool",                  VarI1FromBool},
{FALSE, 250, "VarI1FromCy",                    VarI1FromCy},
{FALSE, 249, "VarI1FromDate",                  VarI1FromDate},
{FALSE, 256, "VarI1FromDec",                   VarI1FromDec},
{FALSE, 252, "VarI1FromDisp",                  VarI1FromDisp},
{FALSE, 245, "VarI1FromI2",                    VarI1FromI2},
{FALSE, 246, "VarI1FromI4",                    VarI1FromI4},
{FALSE, 247, "VarI1FromR4",                    VarI1FromR4},
{FALSE, 248, "VarI1FromR8",                    VarI1FromR8},
{FALSE, 251, "VarI1FromStr",                   VarI1FromStr},
{FALSE, 244, "VarI1FromUI1",                   VarI1FromUI1},
{FALSE, 254, "VarI1FromUI2",                   VarI1FromUI2},
{FALSE, 255, "VarI1FromUI4",                   VarI1FromUI4},
{FALSE,  56, "VarI2FromBool",                  VarI2FromBool},
{FALSE,  52, "VarI2FromCy",                    VarI2FromCy},
{FALSE,  53, "VarI2FromDate",                  VarI2FromDate},
{FALSE, 208, "VarI2FromDec",                   VarI2FromDec},
{FALSE,  55, "VarI2FromDisp",                  VarI2FromDisp},
{FALSE, 205, "VarI2FromI1",                    VarI2FromI1},
{FALSE,  49, "VarI2FromI4",                    VarI2FromI4},
{FALSE,  50, "VarI2FromR4",                    VarI2FromR4},
{FALSE,  51, "VarI2FromR8",                    VarI2FromR8},
{FALSE,  54, "VarI2FromStr",                   VarI2FromStr},
{FALSE,  48, "VarI2FromUI1",                   VarI2FromUI1},
{FALSE, 206, "VarI2FromUI2",                   VarI2FromUI2},
{FALSE, 207, "VarI2FromUI4",                   VarI2FromUI4},
{FALSE,  66, "VarI4FromBool",                  VarI4FromBool},
{FALSE,  62, "VarI4FromCy",                    VarI4FromCy},
{FALSE,  63, "VarI4FromDate",                  VarI4FromDate},
{FALSE, 212, "VarI4FromDec",                   VarI4FromDec},
{FALSE,  65, "VarI4FromDisp",                  VarI4FromDisp},
{FALSE, 209, "VarI4FromI1",                    VarI4FromI1},
{FALSE,  59, "VarI4FromI2",                    VarI4FromI2},
{FALSE,  60, "VarI4FromR4",                    VarI4FromR4},
{FALSE,  61, "VarI4FromR8",                    VarI4FromR8},
{FALSE,  64, "VarI4FromStr",                   VarI4FromStr},
{FALSE,  58, "VarI4FromUI1",                   VarI4FromUI1},
{FALSE, 210, "VarI4FromUI2",                   VarI4FromUI2},
{FALSE, 211, "VarI4FromUI4",                   VarI4FromUI4},
{FALSE, 153, "VarIdiv",                        VarIdiv},
{FALSE, 154, "VarImp",                         VarImp},
{FALSE, 172, "VarInt",                         VarInt},
{FALSE, 155, "VarMod",                         VarMod},
{FALSE, 129, "VarMonthName",                   VarMonthName},
{FALSE, 156, "VarMul",                         VarMul},
{FALSE, 173, "VarNeg",                         VarNeg},
{FALSE, 174, "VarNot",                         VarNot},
{FALSE,  47, "VarNumFromParseNum",             VarNumFromParseNum},
{FALSE, 157, "VarOr",                          VarOr},
{FALSE,  46, "VarParseNumFromStr",             VarParseNumFromStr},
{FALSE, 158, "VarPow",                         VarPow},
{FALSE, 316, "VarR4CmpR8",                     VarR4CmpR8},
{FALSE,  76, "VarR4FromBool",                  VarR4FromBool},
{FALSE,  72, "VarR4FromCy",                    VarR4FromCy},
{FALSE,  73, "VarR4FromDate",                  VarR4FromDate},
{FALSE, 216, "VarR4FromDec",                   VarR4FromDec},
{FALSE,  75, "VarR4FromDisp",                  VarR4FromDisp},
{FALSE, 213, "VarR4FromI1",                    VarR4FromI1},
{FALSE,  69, "VarR4FromI2",                    VarR4FromI2},
{FALSE,  70, "VarR4FromI4",                    VarR4FromI4},
{FALSE,  71, "VarR4FromR8",                    VarR4FromR8},
{FALSE,  74, "VarR4FromStr",                   VarR4FromStr},
{FALSE,  68, "VarR4FromUI1",                   VarR4FromUI1},
{FALSE, 214, "VarR4FromUI2",                   VarR4FromUI2},
{FALSE, 215, "VarR4FromUI4",                   VarR4FromUI4},
{FALSE,  86, "VarR8FromBool",                  VarR8FromBool},
{FALSE,  82, "VarR8FromCy",                    VarR8FromCy},
{FALSE,  83, "VarR8FromDate",                  VarR8FromDate},
{FALSE, 220, "VarR8FromDec",                   VarR8FromDec},
{FALSE,  85, "VarR8FromDisp",                  VarR8FromDisp},
{FALSE, 217, "VarR8FromI1",                    VarR8FromI1},
{FALSE,  79, "VarR8FromI2",                    VarR8FromI2},
{FALSE,  80, "VarR8FromI4",                    VarR8FromI4},
{FALSE,  81, "VarR8FromR4",                    VarR8FromR4},
{FALSE,  84, "VarR8FromStr",                   VarR8FromStr},
{FALSE,  78, "VarR8FromUI1",                   VarR8FromUI1},
{FALSE, 218, "VarR8FromUI2",                   VarR8FromUI2},
{FALSE, 219, "VarR8FromUI4",                   VarR8FromUI4},
{FALSE, 315, "VarR8Pow",                       VarR8Pow},
{FALSE, 317, "VarR8Round",                     VarR8Round},
{FALSE, 175, "VarRound",                       VarRound},
{FALSE, 159, "VarSub",                         VarSub},
{FALSE, 140, "VarTokenizeFormatString",        VarTokenizeFormatString},
{FALSE, 138, "VarUI1FromBool",                 VarUI1FromBool},
{FALSE, 134, "VarUI1FromCy",                   VarUI1FromCy},
{FALSE, 135, "VarUI1FromDate",                 VarUI1FromDate},
{FALSE, 240, "VarUI1FromDec",                  VarUI1FromDec},
{FALSE, 137, "VarUI1FromDisp",                 VarUI1FromDisp},
{FALSE, 237, "VarUI1FromI1",                   VarUI1FromI1},
{FALSE, 130, "VarUI1FromI2",                   VarUI1FromI2},
{FALSE, 131, "VarUI1FromI4",                   VarUI1FromI4},
{FALSE, 132, "VarUI1FromR4",                   VarUI1FromR4},
{FALSE, 133, "VarUI1FromR8",                   VarUI1FromR8},
{FALSE, 136, "VarUI1FromStr",                  VarUI1FromStr},
{FALSE, 238, "VarUI1FromUI2",                  VarUI1FromUI2},
{FALSE, 239, "VarUI1FromUI4",                  VarUI1FromUI4},
{FALSE, 266, "VarUI2FromBool",                 VarUI2FromBool},
{FALSE, 263, "VarUI2FromCy",                   VarUI2FromCy},
{FALSE, 262, "VarUI2FromDate",                 VarUI2FromDate},
{FALSE, 269, "VarUI2FromDec",                  VarUI2FromDec},
{FALSE, 265, "VarUI2FromDisp",                 VarUI2FromDisp},
{FALSE, 267, "VarUI2FromI1",                   VarUI2FromI1},
{FALSE, 258, "VarUI2FromI2",                   VarUI2FromI2},
{FALSE, 259, "VarUI2FromI4",                   VarUI2FromI4},
{FALSE, 260, "VarUI2FromR4",                   VarUI2FromR4},
{FALSE, 261, "VarUI2FromR8",                   VarUI2FromR8},
{FALSE, 264, "VarUI2FromStr",                  VarUI2FromStr},
{FALSE, 257, "VarUI2FromUI1",                  VarUI2FromUI1},
{FALSE, 268, "VarUI2FromUI4",                  VarUI2FromUI4},
{FALSE, 279, "VarUI4FromBool",                 VarUI4FromBool},
{FALSE, 276, "VarUI4FromCy",                   VarUI4FromCy},
{FALSE, 275, "VarUI4FromDate",                 VarUI4FromDate},
{FALSE, 282, "VarUI4FromDec",                  VarUI4FromDec},
{FALSE, 278, "VarUI4FromDisp",                 VarUI4FromDisp},
{FALSE, 280, "VarUI4FromI1",                   VarUI4FromI1},
{FALSE, 271, "VarUI4FromI2",                   VarUI4FromI2},
{FALSE, 272, "VarUI4FromI4",                   VarUI4FromI4},
{FALSE, 273, "VarUI4FromR4",                   VarUI4FromR4},
{FALSE, 274, "VarUI4FromR8",                   VarUI4FromR8},
{FALSE, 277, "VarUI4FromStr",                  VarUI4FromStr},
{FALSE, 270, "VarUI4FromUI1",                  VarUI4FromUI1},
{FALSE, 281, "VarUI4FromUI2",                  VarUI4FromUI2},
{FALSE, 331, "VarUdateFromDate",               VarUdateFromDate},
{FALSE, 128, "VarWeekdayName",                 VarWeekdayName},
{FALSE, 167, "VarXor",                         VarXor},
{FALSE,  12, "VariantChangeType",              VariantChangeType},
{FALSE, 147, "VariantChangeTypeEx",            VariantChangeTypeEx},
{FALSE,   9, "VariantClear",                   VariantClear},
{FALSE,  10, "VariantCopy",                    VariantCopy},
{FALSE,  11, "VariantCopyInd",                 VariantCopyInd},
{FALSE,   8, "VariantInit",                    VariantInit},
{FALSE,  13, "VariantTimeToDosDateTime",       VariantTimeToDosDateTime},
{FALSE, 185, "VariantTimeToSystemTime",        VariantTimeToSystemTime},
{FALSE, 413, "VectorFromBstr",                 VectorFromBstr},
{FALSE,   0, NULL,                             NULL}};
